@@ -22,6 +22,19 @@ dummy_r6 <- function() R6::R6Class
 #' @param timeout Timeout in milliseconds, for the wait or the I/O
 #'   polling.
 #'
+#' @section Batch files:
+#' Running Windows batch files (`.bat` or `.cmd` files) may be complicated
+#' because of the `cmd.exe` command line parsing rules. For example you
+#' cannot easily have whitespace in both the command (path) and one of the
+#' arguments. To work around these limitations you need to start a
+#' `cmd.exe` shell explicitly and use its `call` command. For example:
+#'
+#' ```r
+#' process$new("cmd.exe", c("/c", "call", bat_file, "arg 1", "arg 2"))
+#' ```
+#'
+#' This works even if `bat_file` contains whitespace characters.
+#'
 #' @section Polling:
 #' The `poll_io()` function polls the standard output and standard
 #' error connections of a process, with a timeout. If there is output
@@ -85,7 +98,9 @@ process <- R6::R6Class(
     #'   Note that this argument is not passed to a shell, so no
     #'   tilde-expansion or variable substitution is performed on it.
     #'   It should not be quoted with [base::shQuote()]. See
-    #'   [base::normalizePath()] for tilde-expansion.
+    #'   [base::normalizePath()] for tilde-expansion. If you want to run
+    #'   `.bat` or `.cmd` files on Windows, make sure you read the
+    #'   'Batch files' section above.
     #' @param args Character vector, arguments to the command. They will be
     #'   passed to the process as is, without a shell transforming them,
     #'   They don't need to be escaped.
@@ -94,10 +109,16 @@ process <- R6::R6Class(
     #'     provided;
     #'   * a file name, use this file as standard input;
     #'   * `"|"`: create a (writeable) connection for stdin.
+    #'   * `""` (empty string): inherit it from the main R process. If the
+    #'     main R process does not have a standard input stream, e.g. in
+    #'     RGui on Windows, then an error is thrown.
     #' @param stdout  What to do with the standard output. Possible values:
     #'   * `NULL`: discard it;
     #'   * a string, redirect it to this file;
     #'   * `"|"`: create a connection for it.
+    #'   * `""` (empty string): inherit it from the main R process. If the
+    #'     main R process does not have a standard output stream, e.g. in
+    #'     RGui on Windows, then an error is thrown.
     #' @param stderr What to do with the standard error. Possible values:
     #'   * `NULL`: discard it;
     #'   * a string, redirect it to this file;
@@ -105,6 +126,9 @@ process <- R6::R6Class(
     #'   * `"2>&1"`: redirect it to the same connection (i.e. pipe or file)
     #'     as `stdout`. `"2>&1"` is a way to keep standard output and error
     #'     correctly interleaved.
+    #'   * `""` (empty string): inherit it from the main R process. If the
+    #'     main R process does not have a standard error stream, e.g. in
+    #'     RGui on Windows, then an error is thrown.
     #' @param pty Whether to create a pseudo terminal (pty) for the
     #'   background process. This is currently only supported on Unix
     #'   systems, but not supported on Solaris.
@@ -138,7 +162,10 @@ process <- R6::R6Class(
     #'   cannot function correctly if some environment variables are not
     #'   set, so we always set `HOMEDRIVE`, `HOMEPATH`, `LOGONSERVER`,
     #'   `PATH`, `SYSTEMDRIVE`, `SYSTEMROOT`, `TEMP`, `USERDOMAIN`,
-    #'   `USERNAME`, `USERPROFILE` and `WINDIR`.
+    #'   `USERNAME`, `USERPROFILE` and `WINDIR`. To append new environment
+    #'   variables to the ones set in the current process, specify
+    #'   `"current"` in `env`, without a name, and the appended ones with
+    #'   names. The appended ones can overwrite the current ones.
     #' @param cleanup Whether to kill the process when the `process`
     #'   object is garbage collected.
     #' @param cleanup_tree Whether to kill the process and its child
@@ -154,6 +181,10 @@ process <- R6::R6Class(
     #'   on Windows. It is ignored on other platforms.
     #' @param windows_hide_window Whether to hide the application's window
     #'   on Windows. It is ignored on other platforms.
+    #' @param windows_detached_process Whether to use the
+    #'   `DETACHED_PROCESS` flag on Windows. If this is `TRUE`, then
+    #'   the child process will have no attached console, even if the
+    #'   parent had one.
     #' @param encoding The encoding to assume for `stdin`, `stdout` and
     #'   `stderr`. By default the encoding of the current locale is
     #'   used. Note that `processx` always reencodes the output of the
@@ -169,13 +200,15 @@ process <- R6::R6Class(
       pty_options = list(), connections = list(), poll_connection = NULL,
       env = NULL, cleanup = TRUE, cleanup_tree = FALSE, wd = NULL,
       echo_cmd = FALSE, supervise = FALSE, windows_verbatim_args = FALSE,
-      windows_hide_window = FALSE, encoding = "",  post_process = NULL)
+      windows_hide_window = FALSE, windows_detached_process = !cleanup,
+      encoding = "",  post_process = NULL)
 
       process_initialize(self, private, command, args, stdin,
                          stdout, stderr, pty, pty_options, connections,
                          poll_connection, env, cleanup, cleanup_tree, wd,
                          echo_cmd, supervise, windows_verbatim_args,
-                         windows_hide_window, encoding, post_process),
+                         windows_hide_window, windows_detached_process,
+                         encoding, post_process),
 
     #' @description
     #' Cleanup method that is called when the `process` object is garbage
@@ -422,7 +455,7 @@ process <- R6::R6Class(
     #' `$read_all_output()` waits for all standard output from the process.
     #' It does not return until the process has finished.
     #' Note that this process involves waiting for the process to finish,
-    #' polling for I/O and potentically several `readLines()` calls.
+    #' polling for I/O and potentially several `readLines()` calls.
     #' It returns a character scalar. This will return content only if
     #' `stdout="|"` was used. Otherwise, it will throw an error.
 
@@ -433,7 +466,7 @@ process <- R6::R6Class(
     #' `$read_all_error()` waits for all standard error from the process.
     #' It does not return until the process has finished.
     #' Note that this process involves waiting for the process to finish,
-    #' polling for I/O and potentically several `readLines()` calls.
+    #' polling for I/O and potentially several `readLines()` calls.
     #' It returns a character scalar. This will return content only if
     #' `stderr="|"` was used. Otherwise, it will throw an error.
 
@@ -444,7 +477,7 @@ process <- R6::R6Class(
     #' `$read_all_output_lines()` waits for all standard output lines
     #' from a process. It does not return until the process has finished.
     #' Note that this process involves waiting for the process to finish,
-    #' polling for I/O and potentically several `readLines()` calls.
+    #' polling for I/O and potentially several `readLines()` calls.
     #' It returns a character vector. This will return content only if
     #' `stdout="|"` was used. Otherwise, it will throw an error.
 
@@ -455,7 +488,7 @@ process <- R6::R6Class(
     #' `$read_all_error_lines()` waits for all standard error lines from
     #' a process. It does not return until the process has finished.
     #' Note that this process involves waiting for the process to finish,
-    #' polling for I/O and potentically several `readLines()` calls.
+    #' polling for I/O and potentially several `readLines()` calls.
     #' It returns a character vector. This will return content only if
     #' `stderr="|"` was used. Otherwise, it will throw an error.
 
